@@ -1,19 +1,23 @@
+from __future__ import annotations
+
+from typing import Any
+
 from checkov.common.models.enums import CheckResult, CheckCategories
 from checkov.arm.base_resource_check import BaseResourceCheck
 
-# https://docs.microsoft.com/en-us/azure/templates/microsoft.dbforpostgresql/servers
-# https://docs.microsoft.com/en-us/azure/templates/microsoft.dbforpostgresql/servers/configurations
-# https://docs.microsoft.com/en-us/rest/api/postgresql/configurations/listbyserver#examples
 
 class PostgreSQLServerLogCheckpointsEnabled(BaseResourceCheck):
-    def __init__(self):
+    def __init__(self) -> None:
+        # https://docs.microsoft.com/en-us/azure/templates/microsoft.dbforpostgresql/servers
+        # https://docs.microsoft.com/en-us/azure/templates/microsoft.dbforpostgresql/servers/configurations
+        # https://docs.microsoft.com/en-us/rest/api/postgresql/configurations/listbyserver#examples
         name = "Ensure server parameter 'log_checkpoints' is set to 'ON' for PostgreSQL Database Server"
         id = "CKV_AZURE_30"
-        supported_resources = ['Microsoft.DBforPostgreSQL/servers/configurations', 'configurations']
-        categories = [CheckCategories.NETWORKING]
+        supported_resources = ('Microsoft.DBforPostgreSQL/servers/configurations', 'configurations')
+        categories = (CheckCategories.NETWORKING,)
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def scan_resource_conf(self, conf):
+    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
         if "type" in conf:
             if conf["type"] == "Microsoft.DBforPostgreSQL/servers/configurations":
                 if "name" in conf and conf["name"] == "log_checkpoints":
