@@ -2,6 +2,7 @@ from __future__ import annotations
 
 from typing import Any
 
+from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.graph.graph_builder.graph_components.blocks import Block
 
 
@@ -15,4 +16,4 @@ class BicepBlock(Block):
         attributes: dict[str, Any],
         id: str = "",
     ) -> None:
-        super().__init__(name, config, path, block_type, attributes, id, "Bicep")
+        super().__init__(name, config, path, block_type, attributes, id, GraphSource.BICEP)
