@@ -17,7 +17,7 @@ from checkov.cloudformation.image_referencer.manager import CloudFormationImageR
 from checkov.cloudformation.parser.cfn_keywords import TemplateSections
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
-from checkov.common.graph.db_connectors.networkx.networkx_db_connector import NetworkxConnector
+from checkov.common.typing import LibraryGraphConnector
 from checkov.common.graph.graph_builder import CustomAttributes
 from checkov.common.graph.graph_builder.consts import GraphSource
 from checkov.common.images.image_referencer import ImageReferencerMixin
@@ -40,15 +40,14 @@ class Runner(ImageReferencerMixin[None], BaseRunner[CloudformationGraphManager])
 
     def __init__(
             self,
-            db_connector: NetworkxConnector | None = None,
+            db_connector: LibraryGraphConnector | None = None,
             source: str = GraphSource.CLOUDFORMATION,
             graph_class: Type[CloudformationLocalGraph] = CloudformationLocalGraph,
             graph_manager: CloudformationGraphManager | None = None,
             external_registries: list[BaseRegistry] | None = None
     ) -> None:
-        db_connector = db_connector or NetworkxConnector()
-
         super().__init__(file_extensions=['.json', '.yml', '.yaml', '.template'])
+        db_connector = db_connector or self.db_connector
         self.external_registries = [] if external_registries is None else external_registries
         self.graph_class = graph_class
         self.graph_manager: CloudformationGraphManager = (
