@@ -15,12 +15,12 @@ from pathlib import Path
 from time import sleep
 from typing import List, Dict, TYPE_CHECKING, Any, cast
 
-import boto3  # type:ignore[import]
-import dpath.util
+import boto3
+import dpath
 import requests
 import urllib3
-from botocore.exceptions import ClientError  # type:ignore[import]
-from botocore.config import Config  # type:ignore[import]
+from botocore.exceptions import ClientError
+from botocore.config import Config
 from cachetools import cached, TTLCache
 from colorama import Style
 from termcolor import colored
@@ -48,9 +48,9 @@ from checkov.version import version as checkov_version
 
 if TYPE_CHECKING:
     import argparse
-    from botocore.client import BaseClient  # type:ignore[import]
     from checkov.common.bridgecrew.bc_source import SourceType
     from checkov.common.output.report import Report
+    from mypy_boto3_s3.client import S3Client
     from requests import Response
     from typing_extensions import TypeGuard
 
@@ -86,7 +86,7 @@ CI_METADATA_EXTRACTOR = registry.get_extractor()
 class BcPlatformIntegration:
     def __init__(self) -> None:
         self.bc_api_key = read_key()
-        self.s3_client: BaseClient | None = None
+        self.s3_client: S3Client | None = None
         self.bucket: str | None = None
         self.credentials: dict[str, str] | None = None
         self.repo_path: str | None = None
@@ -191,31 +191,40 @@ class BcPlatformIntegration:
         token: str = json.loads(request.data.decode("utf8"))['token']
         return token
 
-    def setup_http_manager(self, ca_certificate: str | None = None) -> None:
+    def setup_http_manager(self, ca_certificate: str | None = None, no_cert_verify: bool = False) -> None:
         """
         bridgecrew uses both the urllib3 and requests libraries, while checkov uses the requests library.
         :param ca_certificate: an optional CA bundle to be used by both libraries.
+        :param no_cert_verify: whether to skip SSL cert verification
         """
         ca_certificate = ca_certificate or os.getenv('BC_CA_BUNDLE')
+        cert_reqs: str | None
 
         if self.http:
             return
         if ca_certificate:
             os.environ['REQUESTS_CA_BUNDLE'] = ca_certificate
-            try:
-                parsed_url = urllib3.util.parse_url(os.environ['https_proxy'])
-                self.http = urllib3.ProxyManager(os.environ['https_proxy'], cert_reqs='REQUIRED',
-                                                 ca_certs=ca_certificate,
-                                                 proxy_headers=urllib3.make_headers(proxy_basic_auth=parsed_url.auth))  # type:ignore[no-untyped-call]
-            except KeyError:
-                self.http = urllib3.PoolManager(cert_reqs='REQUIRED', ca_certs=ca_certificate)
-        else:
+            cert_reqs = 'CERT_NONE' if no_cert_verify else 'REQUIRED'
+            logging.debug(f'Using CA cert {ca_certificate} and cert_reqs {cert_reqs}')
             try:
                 parsed_url = urllib3.util.parse_url(os.environ['https_proxy'])
                 self.http = urllib3.ProxyManager(os.environ['https_proxy'],
+                                                 cert_reqs=cert_reqs,
+                                                 ca_certs=ca_certificate,
                                                  proxy_headers=urllib3.make_headers(proxy_basic_auth=parsed_url.auth))  # type:ignore[no-untyped-call]
             except KeyError:
-                self.http = urllib3.PoolManager()
+                self.http = urllib3.PoolManager(cert_reqs=cert_reqs, ca_certs=ca_certificate)
+        else:
+            cert_reqs = 'CERT_NONE' if no_cert_verify else None
+            logging.debug(f'Using cert_reqs {cert_reqs}')
+            try:
+                parsed_url = urllib3.util.parse_url(os.environ['https_proxy'])
+                self.http = urllib3.ProxyManager(os.environ['https_proxy'],
+                                                 cert_reqs=cert_reqs,
+                                                 proxy_headers=urllib3.make_headers(proxy_basic_auth=parsed_url.auth))  # type:ignore[no-untyped-call]
+            except KeyError:
+                self.http = urllib3.PoolManager(cert_reqs=cert_reqs)
+        logging.debug('Successfully set up HTTP manager')
 
     def setup_bridgecrew_credentials(
         self,
@@ -404,7 +413,7 @@ class BcPlatformIntegration:
         Persist checkov's scan result into bridgecrew's platform.
         :param scan_reports: List of checkov scan reports
         """
-        if not self.use_s3_integration:
+        if not self.use_s3_integration or not self.s3_client:
             return
         if not self.bucket or not self.repo_path:
             logging.error(f"Something went wrong: bucket {self.bucket}, repo path {self.repo_path}")
@@ -416,10 +425,13 @@ class BcPlatformIntegration:
         reduced_scan_reports = reduce_scan_reports(self.scan_reports)
         checks_metadata_paths = enrich_and_persist_checks_metadata(self.scan_reports, self.s3_client, self.bucket,
                                                                    self.repo_path)
-        dpath.util.merge(reduced_scan_reports, checks_metadata_paths)
+        dpath.merge(reduced_scan_reports, checks_metadata_paths)
         persist_checks_results(reduced_scan_reports, self.s3_client, self.bucket, self.repo_path)
 
     def persist_image_scan_results(self, report: dict[str, Any] | None, file_path: str, image_name: str, branch: str) -> None:
+        if not self.s3_client:
+            logging.error("S3 upload was not correctly initialized")
+            return
         if not self.bucket or not self.repo_path:
             logging.error("Bucket or repo_path was not set")
             return
@@ -441,23 +453,27 @@ class BcPlatformIntegration:
                           ' enabled it via env var CKV_VALIDATE_SECRETS and provide an api key')
             return None
 
+        if not self.s3_client:
+            logging.error("S3 upload was not correctly initialized")
+            return None
+
         base_path = re.sub(REPO_PATH_PATTERN, r'original_secrets/\1', self.repo_path)
         s3_path = f'{base_path}/{uuid.uuid4()}.json'
         try:
-            _put_json_object(self.s3_client, enriched_secrets, self.bucket, s3_path)
+            _put_json_object(self.s3_client, enriched_secrets, self.bucket, s3_path, log_stack_trace_on_error=False)
         except ClientError:
             logging.warning("Got access denied, retrying as s3 role changes should be propagated")
             sleep(4)
             try:
-                _put_json_object(self.s3_client, enriched_secrets, self.bucket, s3_path)
+                _put_json_object(self.s3_client, enriched_secrets, self.bucket, s3_path, log_stack_trace_on_error=False)
             except ClientError:
-                logging.error("Getting access denied consistently, aborting secrets verification")
+                logging.error("Getting access denied consistently, skipping secrets verification, please try again")
                 return None
 
         return s3_path
 
     def persist_run_metadata(self, run_metadata: dict[str, str | list[str]]) -> None:
-        if not self.use_s3_integration:
+        if not self.use_s3_integration or not self.s3_client:
             return
         if not self.bucket or not self.repo_path:
             logging.error(f"Something went wrong: bucket {self.bucket}, repo path {self.repo_path}")
@@ -465,7 +481,7 @@ class BcPlatformIntegration:
         persist_run_metadata(run_metadata, self.s3_client, self.bucket, self.repo_path)
 
     def persist_logs_stream(self, logs_stream: StringIO) -> None:
-        if not self.use_s3_integration:
+        if not self.use_s3_integration or not self.s3_client:
             return
         if not self.bucket or not self.repo_path:
             logging.error(f"Something went wrong: bucket {self.bucket}, repo path {self.repo_path}")
