@@ -140,7 +140,7 @@ class ImageScanner:
             return None
 
     @staticmethod
-    async def get_scan_results_from_cache_async(session: ClientSession, image_id: str) -> Dict[str, Any] | None:
+    async def get_scan_results_from_cache_async(session: ClientSession, image_id: str) -> Dict[str, Any]:
         """
         This is an async implementation of `get_scan_results_from_cache`. The only change is we're getting a session
         as an input, and the asyncio behavior is managed in the calling method.
@@ -163,19 +163,19 @@ class ImageScanner:
             return {}
 
     @staticmethod
-    def _extract_cache_results_for_image(image_id: str, response_json: dict[str, str]) -> dict[str, Any] | None:
-        output_type = response_json["outputType"]
-        logging.info(f"{output_type} returned from cache for image_id={image_id}")
-        if output_type == "Error":
-            logging.error(response_json["outputData"])
-            return None
-        elif output_type == "Result":
+    def _extract_cache_results_for_image(image_id: str, response_json: dict[str, str]) -> dict[str, Any]:
+        output_type = response_json.get("outputType")
+        logging.info(f"output_type={output_type} returned from cache for image_id={image_id}")
+        if output_type == "Result":
             result: dict[str, Any] = json.loads(
                 decompress_file_gzip_base64(
                     response_json["outputData"]
                 )
             )
             return result
+        if output_type is None or output_type == "Error":
+            logging.error(response_json.get("outputData"))
+            return {}
         logging.info(f"Got an empty result for image={image_id}")
         return {}
 
