@@ -31,6 +31,7 @@ from checkov.common.output.csv import CSVSBOM
 from checkov.common.output.cyclonedx import CycloneDX
 from checkov.common.output.gitlab_sast import GitLabSast
 from checkov.common.output.report import Report, merge_reports
+from checkov.common.output.sarif import Sarif
 from checkov.common.parallelizer.parallel_runner import parallel_runner
 from checkov.common.typing import _ExitCodeThresholds, _BaseRunner, _ScaExitCodeThresholds
 from checkov.common.util import data_structures_utils
@@ -58,8 +59,14 @@ OUTPUT_DELIMITER = "\n--- OUTPUT DELIMITER ---\n"
 
 
 class RunnerRegistry:
-    def __init__(self, banner: str, runner_filter: RunnerFilter, *runners: _BaseRunner,
-                 secrets_omitter_class: Type[SecretsOmitter] = SecretsOmitter) -> None:
+    def __init__(
+        self,
+        banner: str,
+        runner_filter: RunnerFilter,
+        *runners: _BaseRunner,
+        tool: str = tool_name,
+        secrets_omitter_class: Type[SecretsOmitter] = SecretsOmitter,
+    ) -> None:
         self.logger = logging.getLogger(__name__)
         self.runner_filter = runner_filter
         self.runners = list(runners)
@@ -67,7 +74,7 @@ class RunnerRegistry:
         self.scan_reports: list[Report] = []
         self.image_referencing_runners = self._get_image_referencing_runners()
         self.filter_runner_framework()
-        self.tool = tool_name
+        self.tool = tool
         self._check_type_to_report_map: dict[str, Report] = {}  # used for finding reports with the same check type
         self.licensing_integration = licensing_integration  # can be maniuplated by unit tests
         self.secrets_omitter_class = secrets_omitter_class
@@ -383,7 +390,7 @@ class RunnerRegistry:
             ansi_escape = re.compile(r'(?:\x1B[@-_]|[\x80-\x9F])[0–9:;<=>?]*[ -/]*[@-~]')
             data_outputs['cli'] = ansi_escape.sub('', cli_output)
         if "sarif" in config.output:
-            master_report = Report("merged")
+            sarif = Sarif(reports=sarif_reports, tool=self.tool)
 
             output_format = output_formats["sarif"]
             if "cli" not in config.output and output_format == CONSOLE_OUTPUT:
@@ -399,22 +406,19 @@ class RunnerRegistry:
                         use_bc_ids=config.output_bc_ids,
                         summary_position=config.summary_position
                     ))
-                master_report.failed_checks += report.failed_checks
-                master_report.skipped_checks += report.skipped_checks
 
             if output_format == CONSOLE_OUTPUT:
                 # don't write to file, if an explicit file path was set
-                master_report.write_sarif_output(self.tool)
+                sarif.write_sarif_output()
 
-            if output_format == CONSOLE_OUTPUT:
                 del output_formats["sarif"]
 
                 if "cli" not in config.output and url:
-                    print("More details: {}".format(url))
+                    print(f"More details: {url}")
                 if CONSOLE_OUTPUT in output_formats.values():
                     print(OUTPUT_DELIMITER)
 
-            data_outputs["sarif"] = json.dumps(master_report.get_sarif_json(self.tool), cls=CustomJSONEncoder)
+            data_outputs["sarif"] = json.dumps(sarif.json, cls=CustomJSONEncoder)
         if "json" in config.output:
             if config.compact and report_jsons:
                 self.strip_code_blocks_from_json(report_jsons)
