@@ -12,7 +12,7 @@ def convert_to_unix_path(path: str) -> str:
 
 def extract_tar_archive(source_path: str, dest_path: str) -> None:
     with tarfile.open(source_path) as tar:
-        tar.extractall(path=dest_path)
+        tar.extractall(path=dest_path)  # nosec  # only trusted source
 
 
 def compress_file_gzip_base64(input_path: str) -> str:
