@@ -2,10 +2,10 @@ from __future__ import annotations
 
 from abc import abstractmethod
 
-from bc_jsonpath_ng import parse
 from typing import Any
 
 from checkov.common.models.enums import CheckCategories, CheckResult
+from checkov.common.util.json_utils import get_jsonpath_from_evaluated_key
 from checkov.github.base_github_configuration_check import BaseGithubCheck
 from checkov.github.schemas.org_security import schema as org_security_schema
 from checkov.json_doc.enums import BlockType
@@ -24,8 +24,8 @@ class OrgSecurity(BaseGithubCheck):
 
     def scan_entity_conf(self, conf: dict[str, Any], entity_type: str) -> CheckResult:  # type:ignore[override]
         if org_security_schema.validate(conf):
-            evaluated_key = self.get_evaluated_keys()[0].replace("/", ".")
-            jsonpath_expression = parse(f"$..{evaluated_key}")
+            evaluated_key = self.get_evaluated_keys()[0]
+            jsonpath_expression = get_jsonpath_from_evaluated_key(evaluated_key)
             if all(match.value == self.get_expected_value() for match in jsonpath_expression.find(conf)):
                 return CheckResult.PASSED
             else:
