@@ -17,11 +17,5 @@ class PrivilegedContainersPSP(BaseSpecOmittedOrValueCheck):
     def get_inspected_key(self):
         return "spec/privileged"
 
-    def get_resource_id(self, conf):
-        if "metadata" in conf:
-            if "name" in conf["metadata"]:
-                return 'PodSecurityPolicy.{}'.format(conf["metadata"]["name"])
-        return 'PodSecurityPolicy.spec.privileged'
-
 
 check = PrivilegedContainersPSP()
