@@ -100,6 +100,7 @@ class Runner(PackageRunner):
         exit_code = await process.wait()
 
         if exit_code:
+            logging.error(f"error when running twistcli on image_id {image_id}")
             logging.error(stderr.decode())
             return {}
 
@@ -284,25 +285,6 @@ class Runner(PackageRunner):
                                            f"{image.end_line} ({image_id}))"
             return self.get_report_from_scan_result(result, dockerfile_path, rootless_file_path_to_report,
                                                     image_details, runner_filter)
-
-        elif strtobool(os.getenv("CHECKOV_EXPERIMENTAL_IMAGE_REFERENCING", "False")):
-            # experimental flag on running image referencers via local twistcli
-            image_id = ImageReferencer.inspect(image.name)
-            if not image_id:
-                logging.info(f"Unable to extract image id from {image.name}")
-                return Report(self.check_type)
-            scan_result = self.scan(image_id, dockerfile_path, runner_filter)
-            if scan_result is None:
-                report = Report(self.check_type)
-                report.set_error_status(ErrorStatus.ERROR)
-                return report
-
-            self.raw_report = scan_result
-            result = scan_result.get('results', [{}])[0]
-            rootless_file_path_to_report = f"{dockerfile_path} ({image.name} lines:{image.start_line}-" \
-                                           f"{image.end_line} ({image_id}))"
-            return self.get_report_from_scan_result(result, dockerfile_path, rootless_file_path_to_report, None,
-                                                    runner_filter)
         else:
             logging.info(f"No cache hit for image {image.name}")
 
