@@ -5,9 +5,9 @@ from checkov.serverless.checks.package.registry import package_registry
 
 
 class BasePackageCheck(BaseCheck):
-    def __init__(self, name, id, categories, supported_entities):
+    def __init__(self, name, id, categories, supported_entities, guideline=None):
         super().__init__(name=name, id=id, categories=categories, supported_entities=supported_entities,
-                         block_type="serverless")
+                         block_type="serverless", guideline=guideline)
         package_registry.register(self)
 
     def scan_entity_conf(self, conf, entity_type):
