@@ -1,7 +1,6 @@
 from __future__ import annotations
 
 import json
-import logging
 from typing import Any
 
 from checkov.common.models.enums import CheckResult, CheckCategories
@@ -22,8 +21,7 @@ class BatchJobIsNotPrivileged(BaseResourceCheck):
             if isinstance(container_properties[0], str):
                 try:
                     container = json.loads(container_properties[0])
-                except json.JSONDecodeError as e:
-                    logging.error(e)
+                except json.JSONDecodeError:
                     return CheckResult.UNKNOWN
             else:
                 container = container_properties[0]
