@@ -1,7 +1,9 @@
 import logging
 from typing import Dict, TYPE_CHECKING, Tuple, List, Any
 
-import dpath.util
+import dpath
+
+from checkov.terraform.modules.module_objects import TFDefinitionKey
 
 if TYPE_CHECKING:
     from checkov.terraform.context_parsers.base_parser import BaseContextParser
@@ -24,7 +26,11 @@ class ParserRegistry:
         self, definitions: Tuple[str, Dict[str, List[Dict[str, Any]]]], collect_skip_comments: bool = True
     ) -> Dict[str, Dict[str, Dict[str, Any]]]:
         supported_definitions = [parser_type for parser_type in self.context_parsers.keys()]
-        (tf_file, definition_blocks_types) = definitions
+        (tf_definition_key, definition_blocks_types) = definitions
+        if isinstance(tf_definition_key, TFDefinitionKey):
+            tf_file = tf_definition_key.file_path
+        else:
+            tf_file = tf_definition_key
         if definition_blocks_types:
             definition_blocks_types = {x: definition_blocks_types[x] for x in definition_blocks_types.keys()}
             for definition_type in definition_blocks_types.keys():
