@@ -9,6 +9,7 @@ from typing import List, Optional, Union, Any, Dict, Set, Tuple
 
 from typing_extensions import TypedDict
 
+import checkov.terraform.graph_builder.foreach.consts
 from checkov.common.graph.graph_builder import Edge
 from checkov.common.graph.graph_builder import reserved_attribute_names
 from checkov.common.graph.graph_builder.graph_components.attribute_names import CustomAttributes
@@ -17,9 +18,10 @@ from checkov.common.graph.graph_builder.utils import calculate_hash, join_trimme
 from checkov.common.runners.base_runner import strtobool
 from checkov.common.util.parser_utils import get_abs_path, get_tf_definition_key_from_module_dependency
 from checkov.common.util.type_forcers import force_int
+from checkov.terraform.graph_builder.foreach.builder import ForeachBuilder
+from checkov.terraform.modules.module_objects import TFModule
 from checkov.terraform.checks.utils.dependency_path_handler import unify_dependency_path
 from checkov.terraform.context_parsers.registry import parser_registry
-import checkov.terraform.graph_builder.foreach_handler as foreach_module
 from checkov.terraform.graph_builder.graph_components.block_types import BlockType
 from checkov.terraform.graph_builder.graph_components.blocks import TerraformBlock
 from checkov.terraform.graph_builder.graph_components.generic_resource_encryption import ENCRYPTION_BY_RESOURCE_TYPE
@@ -54,6 +56,8 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         self.vertices_by_module_dependency_by_name: Dict[Tuple[str, str], Dict[BlockType, Dict[str, List[int]]]] = defaultdict(lambda: defaultdict(lambda: defaultdict(list)))
         self.vertices_by_module_dependency: Dict[Tuple[str, str], Dict[BlockType, List[int]]] = defaultdict(lambda: defaultdict(list))
         self.enable_foreach_handling = strtobool(os.getenv('CHECKOV_ENABLE_FOREACH_HANDLING', 'False'))
+        self.enable_modules_foreach_handling = strtobool(os.getenv('CHECKOV_ENABLE_MODULES_FOREACH_HANDLING', 'False'))
+        self.use_new_tf_parser = strtobool(os.getenv('CHECKOV_NEW_TF_PARSER', 'False'))
         self.foreach_blocks: Dict[str, List[int]] = {BlockType.RESOURCE: [], BlockType.MODULE: []}
 
     def build_graph(self, render_variables: bool) -> None:
@@ -63,8 +67,8 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         logging.info(f"[TerraformLocalGraph] created {len(self.edges)} edges")
         if self.enable_foreach_handling:
             try:
-                foreach_handler = foreach_module.ForeachHandler(self)
-                foreach_handler.handle_foreach_rendering(self.foreach_blocks)
+                foreach_builder = ForeachBuilder(self)
+                foreach_builder.handle(self.foreach_blocks)
                 self._arrange_graph_data()
                 self._build_edges()
                 logging.info(f"[TerraformLocalGraph] finished handling foreach values with {len(self.vertices)} vertices and {len(self.edges)} edges")
@@ -91,7 +95,8 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         for i, block in enumerate(self.module.blocks):
             self.vertices[i] = block
             self._add_block_data_to_graph(i, block)
-            if self.enable_foreach_handling and (foreach_module.FOREACH_STRING in block.attributes or foreach_module.COUNT_STRING in block.attributes) \
+            if self.enable_foreach_handling and (
+                    checkov.terraform.graph_builder.foreach.consts.FOREACH_STRING in block.attributes or checkov.terraform.graph_builder.foreach.consts.COUNT_STRING in block.attributes) \
                     and block.block_type in (BlockType.MODULE, BlockType.RESOURCE):
                 self.foreach_blocks[block.block_type].append(i)
 
@@ -103,8 +108,10 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             # map between file paths and module vertices indexes from that file
             self.map_path_to_module.setdefault(block.path, []).append(idx)
 
-        self.vertices_by_module_dependency[(block.module_dependency, block.module_dependency_num)][block.block_type].append(idx)
-        self.vertices_by_module_dependency_by_name[(block.module_dependency, block.module_dependency_num)][block.block_type][block.name].append(idx)
+        if self.use_new_tf_parser:
+            self.vertices_by_module_dependency[block.source_module_object][block.block_type].append(idx)
+        else:
+            self.vertices_by_module_dependency[(block.module_dependency, block.module_dependency_num)][block.block_type].append(idx)
 
         self.in_edges[idx] = []
         self.out_edges[idx] = []
@@ -115,7 +122,6 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         self.vertices_block_name_map = defaultdict(lambda: defaultdict(list))
         self.map_path_to_module = {}
         self.vertices_by_module_dependency = defaultdict(lambda: defaultdict(list))
-        self.vertices_by_module_dependency_by_name = defaultdict(lambda: defaultdict(lambda: defaultdict(list)))
         self.edges = []
         for i in range(len(self.vertices)):
             self.out_edges[i] = []
@@ -124,43 +130,6 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         for i, block in enumerate(self.vertices):
             self._add_block_data_to_graph(i, block)
 
-    def _set_variables_values_from_modules(self) -> List[Undetermined]:
-        undetermined_values: List[Undetermined] = []
-        resources_types = self.get_resources_types_in_graph()
-        for module_vertex_id in self.vertices_by_block_type.get(BlockType.MODULE, []):
-            module_vertex = self.vertices[module_vertex_id]
-            for attribute_name, attribute_value in module_vertex.attributes.items():
-                matching_variables = self.vertices_block_name_map.get(BlockType.VARIABLE, {}).get(attribute_name, [])
-                for variable_vertex_id in matching_variables:
-                    variable_dir = os.path.dirname(self.vertices[variable_vertex_id].path)
-                    # TODO: module_vertex.path is always a string and the retrieved dict value is a nested list
-                    #   therefore this condition is always false. Fixing it results in some variables not being rendered.
-                    #   see test: tests.graph.terraform.variable_rendering.test_render_scenario.TestRendererScenarios.test_account_dirs_and_modules
-                    if module_vertex.path in self.module.module_dependency_map.get(variable_dir, []):
-                        has_var_reference = get_referenced_vertices_in_value(
-                            value=attribute_value, aliases={}, resources_types=resources_types
-                        )
-                        if has_var_reference:
-                            undetermined_values.append(
-                                {
-                                    "module_vertex_id": module_vertex_id,
-                                    "attribute_name": attribute_name,
-                                    "variable_vertex_id": variable_vertex_id,
-                                }
-                            )
-                        var_default_value = self.vertices[variable_vertex_id].attributes.get("default")
-                        if (
-                            not has_var_reference
-                            or not var_default_value
-                            or get_referenced_vertices_in_value(
-                                value=var_default_value, aliases={}, resources_types=resources_types
-                            )
-                        ):
-                            self.update_vertex_attribute(
-                                variable_vertex_id, "default", attribute_value, module_vertex_id, attribute_name
-                            )
-        return undetermined_values
-
     def _get_aliases(self) -> Dict[str, Dict[str, BlockType]]:
         """
         :return aliases: map between alias names that are found inside the blocks and the block type their aliased to.
@@ -176,6 +145,23 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         For each vertex, if it's originated in a module import, add to the vertex the index of the
         matching module vertex as 'source_module'
         """
+        if self.use_new_tf_parser:
+            for vertex in self.vertices:
+                if not vertex.source_module_object:
+                    continue
+                for idx in self.vertices_by_block_type[BlockType.MODULE]:
+                    if vertex.source_module_object.name != self.vertices[idx].name:
+                        continue
+                    if vertex.source_module_object.path != self.vertices[idx].path:
+                        continue
+                    if vertex.source_module_object.nested_tf_module != self.vertices[idx].source_module_object:
+                        continue
+                    if vertex.source_module_object.foreach_idx != self.vertices[idx].for_each_index:
+                        continue
+                    vertex.source_module.add(idx)
+                    break
+            return
+
         block_dirs_to_modules: Dict[Tuple[str, str], Dict[str, Set[int]]] = defaultdict(dict)
         for dir_name, paths_to_modules in self.module.module_dependency_map.items():
             # for each directory, find the module vertex that imported it
@@ -222,6 +208,7 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
     def _build_edges_for_vertex(self, origin_node_index: int, vertex: TerraformBlock, aliases: Dict[str, Dict[str, BlockType]], resources_types: List[str], cross_variable_edges: bool = False, referenced_module: Optional[Dict[str, Any]] = None):
         referenced_module_idx = referenced_module.get("idx") if referenced_module else None
         referenced_module_path = referenced_module.get("path") if referenced_module else None
+        referenced_module_object = referenced_module.get("source_module_object") if referenced_module else None
         for attribute_key, attribute_value in vertex.attributes.items():
             if attribute_key in reserved_attribute_names or attribute_has_nested_attributes(
                     attribute_key, vertex.attributes
@@ -238,25 +225,29 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
                 sub_values = [remove_index_pattern_from_str(sub_value) for sub_value in vertex_reference.sub_parts]
                 for i in range(len(sub_values)):
                     reference_name = join_trimmed_strings(char_to_join=".", str_lst=sub_values, num_to_trim=i)
+                    source_module_object = None
+                    if self.use_new_tf_parser:
+                        source_module_object = vertex.source_module_object
                     if referenced_module is not None:
+                        source_module_object = referenced_module_object if source_module_object else None
                         dest_node_index = self._find_vertex_index_relative_to_path(
                             vertex_reference.block_type, reference_name, referenced_module_path, vertex.module_dependency,
-                            vertex.module_dependency_num, referenced_module_idx
+                            vertex.module_dependency_num, referenced_module_idx, source_module_object=source_module_object
                         )
-                    elif vertex.module_dependency:
+                    elif vertex.module_dependency or hasattr(vertex, "source_module_object"):
                         dest_node_index = self._find_vertex_index_relative_to_path(
                             vertex_reference.block_type, reference_name, vertex.path, vertex.module_dependency,
-                            vertex.module_dependency_num
+                            vertex.module_dependency_num, source_module_object=source_module_object
                         )
                         if dest_node_index == -1:
                             dest_node_index = self._find_vertex_index_relative_to_path(
                                 vertex_reference.block_type, reference_name, vertex.path, vertex.path,
-                                vertex.module_dependency_num
+                                vertex.module_dependency_num, source_module_object=source_module_object
                             )
                     else:
                         dest_node_index = self._find_vertex_index_relative_to_path(
                             vertex_reference.block_type, reference_name, vertex.path, vertex.module_dependency,
-                            vertex.module_dependency_num
+                            vertex.module_dependency_num, source_module_object=source_module_object
                         )
                     if dest_node_index > -1 and origin_node_index > -1:
                         if vertex_reference.block_type == BlockType.MODULE:
@@ -275,19 +266,12 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
 
         if vertex.block_type == BlockType.MODULE and vertex.attributes.get('source') \
                 and isinstance(vertex.attributes.get('source')[0], str):
-            target_path = get_path_with_nested_modules(vertex)
             dest_module_path = self._get_dest_module_path(
                 curr_module_dir=self.get_dirname(vertex.path),
                 dest_module_source=vertex.attributes["source"][0],
                 dest_module_version=vertex.attributes.get("version", ["latest"])[0]
             )
-            target_variables = [
-                index
-                for index in self.vertices_by_module_dependency.get(
-                    (target_path, self.module.module_address_map.get((vertex.path, vertex.name))), {}).get(
-                    BlockType.VARIABLE, [])
-                if self.get_dirname(self.vertices[index].path) == dest_module_path
-            ]
+            target_variables = self._get_target_variables(vertex, dest_module_path)
             for attribute in vertex.attributes.keys():
                 if attribute in MODULE_RESERVED_ATTRIBUTES:
                     continue
@@ -304,6 +288,24 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             if len(target_variables) == 1:
                 self._create_edge(target_variables[0], origin_node_index, "default", cross_variable_edges)
 
+    def _get_target_variables(self, vertex: TerraformBlock, dest_module_path: str) -> list[int]:
+        if self.use_new_tf_parser:
+            target_path = get_vertex_as_tf_module(vertex)
+            return [
+                index
+                for index in self.vertices_by_module_dependency.get(target_path, {}).get(BlockType.VARIABLE, [])
+                if self.get_dirname(self.vertices[index].path) == dest_module_path
+            ]
+        else:
+            target_path = get_path_with_nested_modules(vertex)
+            return [
+                index
+                for index in self.vertices_by_module_dependency.get(
+                    (target_path, self.module.module_address_map.get((vertex.path, vertex.name))), {}).get(
+                    BlockType.VARIABLE, [])
+                if self.get_dirname(self.vertices[index].path) == dest_module_path
+            ]
+
     def _build_cross_variable_edges(self):
         target_nodes_indexes = [v for v, referenced_vertices in self.out_edges.items() if
                                 self.vertices[v].block_type == BlockType.RESOURCE and any(
@@ -365,11 +367,7 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
             )
             for vertex_index in output_blocks_with_name:
                 vertex = self.vertices[vertex_index]
-                if (self.get_dirname(vertex.path) == dest_module_path) and (
-                    vertex.module_dependency == module_node.module_dependency  # The vertex is in the same file
-                    or self.get_abspath(vertex.module_dependency)
-                    == self.get_abspath(module_node.path)  # The vertex is in the correct dependency path
-                ):
+                if self._should_add_edge(vertex, dest_module_path, module_node):
                     added_edge = self._create_edge(origin_node_index, vertex_index, attribute_key, cross_variable_edges)
                     if added_edge:
                         self.vertices[origin_node_index].add_module_connection(attribute_key, vertex_index)
@@ -403,14 +401,16 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
         return os.path.abspath(dest_module_path)
 
     def _find_vertex_index_relative_to_path(
-        self, block_type: BlockType, name: str, block_path: str, module_path: str, module_num: str, relative_module_idx: Optional[int] = None
+        self, block_type: BlockType, name: str, block_path: str, module_path: str, module_num: str, relative_module_idx: Optional[int] = None, source_module_object: Optional[TFModule] = None
     ) -> int:
         relative_vertices = []
-        if relative_module_idx is not None:
+        if self.use_new_tf_parser and relative_module_idx is None:
+            module_dependency_by_name_key = source_module_object
+        elif relative_module_idx is not None:
             module_dependency_by_name_key = next(k for k, v in self.vertices_by_module_dependency.items() if v.get(BlockType.MODULE, []).__contains__(relative_module_idx))
         else:
             module_dependency_by_name_key = (module_path, module_num)
-        possible_vertices = self.vertices_by_module_dependency_by_name.get(module_dependency_by_name_key, {}).get(block_type, {}).get(name, [])
+        possible_vertices = [v for v in self.vertices_by_module_dependency.get(module_dependency_by_name_key, {}).get(block_type, {}) if self.vertices[v].name == name]
         for vertex_index in possible_vertices:
             vertex = self.vertices[vertex_index]
             if self.get_dirname(vertex.path) == self.get_dirname(block_path):
@@ -528,6 +528,8 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
                     v = self.vertices[idx]
                     module_data = v.get_export_data()
                     module_data["idx"] = idx
+                    if hasattr(vertex, "source_module_object"):
+                        module_data["source_module_object"] = v.source_module_object
                     source_module_data.append(module_data)
                 source_module_data.reverse()
                 vertex.breadcrumbs[CustomAttributes.SOURCE_MODULE] = source_module_data
@@ -583,6 +585,22 @@ class TerraformLocalGraph(LocalGraph[TerraformBlock]):
                 vertex_context = vertex_context.get(path, vertex_context)
             vertex_context[CustomAttributes.TF_RESOURCE_ADDRESS] = address
 
+    def _should_add_edge(self, vertex: TerraformBlock, dest_module_path: str, module_node: TerraformBlock) -> bool:
+        if self.use_new_tf_parser:
+            return (self.get_dirname(vertex.path) == dest_module_path) and \
+                (
+                    vertex.source_module_object == module_node.source_module_object  # The vertex is in the same file
+                    or self.get_abspath(vertex.source_module_object.path)
+                    == self.get_abspath(module_node.path)  # The vertex is in the correct dependency path)
+            )
+        else:
+            return (self.get_dirname(vertex.path) == dest_module_path) and \
+                (
+                    vertex.module_dependency == module_node.module_dependency  # The vertex is in the same file
+                    or self.get_abspath(vertex.module_dependency)
+                    == self.get_abspath(module_node.path)  # The vertex is in the correct dependency path
+            )
+
 
 def to_list(data):
     if isinstance(data, list) and len(data) == 1 and (isinstance(data[0], str) or isinstance(data[0], int)):
@@ -662,3 +680,7 @@ def get_path_with_nested_modules(block: TerraformBlock) -> str:
     if not strtobool(os.getenv('CHECKOV_ENABLE_NESTED_MODULES', 'True')):
         return unify_dependency_path([block.module_dependency, block.path])
     return get_tf_definition_key_from_module_dependency(block.path, block.module_dependency, block.module_dependency_num)
+
+
+def get_vertex_as_tf_module(block: TerraformBlock) -> TFModule:
+    return TFModule(block.path, block.name, block.source_module_object)
