@@ -8,7 +8,7 @@ import platform
 from pathlib import Path
 from typing import Dict, Optional, Tuple, Any, Set, TYPE_CHECKING
 
-import dpath.util
+import dpath
 
 from checkov.common.checks_infra.registry import get_graph_checks_registry
 from checkov.common.graph.checks_infra.registry import BaseRegistry
@@ -32,6 +32,7 @@ from checkov.common.util.parser_utils import get_module_from_full_path, get_abs_
 from checkov.common.util.secrets import omit_secret_value_from_checks, omit_secret_value_from_graph_checks
 from checkov.common.variables.context import EvaluationContext
 from checkov.runner_filter import RunnerFilter
+from checkov.terraform.modules.module_objects import TFDefinitionKey
 from checkov.terraform.checks.data.registry import data_registry
 from checkov.terraform.checks.module.registry import module_registry
 from checkov.terraform.checks.provider.registry import provider_registry
@@ -46,6 +47,7 @@ from checkov.terraform.graph_builder.local_graph import TerraformLocalGraph
 from checkov.terraform.graph_manager import TerraformGraphManager
 from checkov.terraform.image_referencer.manager import TerraformImageReferencerManager
 from checkov.terraform.parser import Parser
+from checkov.terraform.tf_parser import TFParser
 from checkov.terraform.plan_utils import get_resource_id_without_nested_modules
 from checkov.terraform.tag_providers import get_resource_tags
 from checkov.common.runners.base_runner import strtobool
@@ -53,6 +55,7 @@ from checkov.common.runners.base_runner import strtobool
 if TYPE_CHECKING:
     from networkx import DiGraph
     from checkov.common.images.image_referencer import Image
+    from checkov.common.typing import TFDefinitionKeyType
 
 # Allow the evaluation of empty variables
 dpath.options.ALLOW_EMPTY_STRING_KEYS = True
@@ -65,7 +68,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
 
     def __init__(
         self,
-        parser: Parser | None = None,
+        parser: Parser | TFParser | None = None,
         db_connector: LibraryGraphConnector | None = None,
         external_registries: list[BaseRegistry] | None = None,
         source: str = GraphSource.TERRAFORM,
@@ -75,8 +78,8 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
         super().__init__(file_extensions=['.tf', '.hcl'])
         self.external_registries = [] if external_registries is None else external_registries
         self.graph_class = graph_class
-        self.parser = parser or Parser()
-        self.definitions: "dict[str, dict[str, Any]] | None" = None
+        self.parser = parser or TFParser() if strtobool(os.getenv('CHECKOV_NEW_TF_PARSER', 'False')) else Parser()
+        self.definitions: dict[TFDefinitionKeyType, dict[str, Any]] | None = None
         self.context = None
         self.breadcrumbs = None
         self.evaluations_context: Dict[str, Dict[str, EvaluationContext]] = {}
@@ -323,7 +326,9 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
         if self.enable_nested_modules:
             self.push_skipped_checks_down_from_modules(self.context)
         for full_file_path, definition in self.definitions.items():
-            self.pbar.set_additional_data({'Current File Scanned': os.path.relpath(full_file_path, root_folder)})
+            self.pbar.set_additional_data({'Current File Scanned': os.path.relpath(
+                full_file_path.file_path if isinstance(full_file_path, TFDefinitionKey) else full_file_path,
+                root_folder)})
             if self.enable_nested_modules:
                 abs_scanned_file = get_abs_path(full_file_path)
                 abs_referrer = None
@@ -404,9 +409,13 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
             else:
                 entity_context_path = entity_context_path_header + block_type + definition_path
             # Entity can exist only once per dir, for file as well
+            if isinstance(full_file_path, TFDefinitionKey):
+                context_path = full_file_path.file_path
+            else:
+                context_path = full_file_path
             try:
                 entity_context = data_structures_utils.get_inner_dict(
-                    definition_context[full_file_path],
+                    definition_context[context_path],
                     entity_context_path,
                 )
                 entity_lines_range = [entity_context.get('start_line'), entity_context.get('end_line')]
@@ -419,7 +428,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
                 skipped_checks = None
 
             if not self.enable_nested_modules and block_type == "module":
-                self.push_skipped_checks_down_old(definition_context, full_file_path, skipped_checks)
+                self.push_skipped_checks_down_old(definition_context, context_path, skipped_checks)
 
             if full_file_path in self.evaluations_context:
                 variables_evaluations = {}
@@ -428,7 +437,10 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
                 entity_evaluations = BaseVariableEvaluation.reduce_entity_evaluations(variables_evaluations,
                                                                                       entity_context_path)
             results = registry.scan(scanned_file, entity, skipped_checks, runner_filter)
-            absolut_scanned_file_path, _ = self._strip_module_referrer(file_path=full_file_path)
+            if isinstance(full_file_path, str):
+                absolute_scanned_file_path, _ = self._strip_module_referrer(file_path=full_file_path)
+            if isinstance(full_file_path, TFDefinitionKey):
+                absolute_scanned_file_path = get_abs_path(full_file_path)
             # This duplicates a call at the start of scan, but adding this here seems better than kludging with some tuple return type
             tags = get_resource_tags(entity_type, entity_config)
             if results:
@@ -451,7 +463,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
                         resource=entity_id,
                         evaluations=entity_evaluations,
                         check_class=check.__class__.__module__,
-                        file_abs_path=absolut_scanned_file_path,
+                        file_abs_path=absolute_scanned_file_path,
                         entity_tags=tags,
                         caller_file_path=caller_file_path,
                         caller_file_line_range=caller_file_line_range,
@@ -477,7 +489,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
                     # resources without checks, but not existing ones
                     report.extra_resources.add(
                         ExtraResource(
-                            file_abs_path=absolut_scanned_file_path,
+                            file_abs_path=absolute_scanned_file_path,
                             file_path=scanned_file,
                             resource=entity_id,
                         )
@@ -499,7 +511,10 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
             if result:
                 file, parse_result, file_parsing_errors = result
                 if parse_result is not None:
-                    self.definitions[file] = parse_result
+                    if isinstance(self.parser, Parser):
+                        self.definitions[file] = parse_result
+                    if isinstance(self.parser, TFParser):
+                        self.definitions[TFDefinitionKey(file_path=file)] = parse_result
                 if file_parsing_errors:
                     parsing_errors.update(file_parsing_errors)
 
@@ -545,7 +560,11 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
 
     def push_skipped_checks_down_from_modules(self, definition_context):
         module_context_parser = parser_registry.context_parsers[BlockType.MODULE]
-        for full_file_path, definition in self.definitions.items():
+        for tf_definition_key, definition in self.definitions.items():
+            if isinstance(tf_definition_key, TFDefinitionKey):
+                full_file_path = tf_definition_key.file_path
+            else:
+                full_file_path = tf_definition_key
             definition_modules_context = definition_context.get(full_file_path, {}).get(BlockType.MODULE, {})
             for entity in definition.get(BlockType.MODULE, []):
                 module_name = module_context_parser.get_entity_context_path(entity)[0]
@@ -557,8 +576,8 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
         # this method pushes the skipped_checks down the 1 level to all resource types.
         if not skipped_checks or not resolved_paths:
             return
-
-        for definition in resolved_paths:
+        resolved_file_paths = [path.file_path if isinstance(path, TFDefinitionKey) else path for path in resolved_paths]
+        for ind, definition in enumerate(resolved_file_paths):
             for block_type, block_configs in definition_context.get(definition, {}).items():
                 # skip if type is not a Terraform resource
                 if block_type not in CHECK_BLOCK_TYPES:
@@ -569,7 +588,7 @@ class Runner(ImageReferencerMixin[None], BaseRunner[TerraformGraphManager]):
                     for module_name, module_config in block_configs.items():
                         # append the skipped checks also from a module to another module
                         module_config["skipped_checks"] += skipped_checks
-                        module_context = next(m for m in self.definitions.get(definition).get(block_type) if module_name in m)
+                        module_context = next(m for m in self.definitions.get(resolved_paths[ind]).get(block_type) if module_name in m)
                         recursive_resolved_paths = module_context.get(module_name).get(RESOLVED_MODULE_ENTRY_NAME)
                         self.push_skipped_checks_down(definition_context, skipped_checks, recursive_resolved_paths)
                 else:
